@@ -1,13 +1,12 @@
 import os
 import re
+from functools import partial
 from itertools import count
 from pathlib import Path
-from typing import List
+from typing import Callable, List
 
 DEFAULT_TIMEOUT = 120
-MIGRATION_REGEX = (
-    "\\((['\"]){app_label}(['\"]),\\s(['\"])(?P<conflict_migration>.*)(['\"])\\),"
-)
+MIGRATION_REGEX = "\\((?P<comma>['\"]){app_label}(['\"]),\\s(['\"])(?P<conflict_migration>.*)(['\"])\\),"
 
 
 def _clean_message(output: str) -> str:
@@ -20,27 +19,42 @@ def _decode_message(output: bytes, encoding: str) -> str:
     return output.decode(encoding).strip()
 
 
-def _update_migration(conflict_path: Path, app_label: str, seen: List[str]) -> None:
+def _update_migration(conflict_path: Path, app_label: str, prev_migration: str) -> None:
     """Modify the migration file."""
-    replacement = "('{app_label}', '{prev_migration}'),".format(
-        app_label=app_label,
-        prev_migration=seen[-1],
-    )
+    regex = MIGRATION_REGEX.format(app_label=app_label)
+    replace_regex = re.compile(regex, re.I)
 
-    replace_regex = re.compile(
-        MIGRATION_REGEX.format(app_label=app_label),
-        re.I | re.M,
-    )
+    match = replace_regex.search(conflict_path.read_text())
 
-    # Update the migration
-    output = re.sub(
-        replace_regex,
-        replacement,
-        conflict_path.read_text(),
-    )
+    if match:
+        comma = match.group("comma")
+        replacement = f"({comma}{app_label}{comma}, {comma}{prev_migration}{comma}),"
 
-    # Write to the conflict file.
-    conflict_path.write_text(output)
+        # Update the migration
+        output = re.sub(
+            replace_regex,
+            replacement,
+            conflict_path.read_text(),
+        )
+
+        # Write to the conflict file.
+        conflict_path.write_text(output)
+    else:  # pragma: no cover
+        raise ValueError(f'Couldn\'t find "{regex}" in {conflict_path.name}')
+
+
+def migration_sorter(path: str, app_label: str) -> int:
+    path = os.path.split(path)[-1]
+    parts = path.split("_")
+    key = parts[0]
+
+    if not str(key).isdigit():
+        raise ValueError(
+            f'Unable to fix migration for "{app_label}" app: {path}\n'
+            f"NOTE: It needs to begin with a number. eg. 0001_*",
+        )
+
+    return int(key)
 
 
 def fix_numbered_migration(
@@ -50,11 +64,14 @@ def fix_numbered_migration(
     seed: int,
     start_name: str,
     changed_files: List[str],
+    writer: Callable[[str], None],
 ):
     """Resolve migration conflicts for numbered migrations."""
     seen = [start_name]
     counter = count(seed + 1)  # 0537 -> 538
-    sorted_changed_files = sorted(changed_files, key=lambda p: p.split("_")[0])
+    sorted_changed_files = sorted(
+        changed_files, key=partial(migration_sorter, app_label=app_label)
+    )
 
     for path in sorted_changed_files:
         next_ = str(next(counter))
@@ -73,32 +90,20 @@ def fix_numbered_migration(
         conflict_new_path = conflict_path.with_name(new_conflict_name)
 
         with conflict_path:
-            _update_migration(conflict_path, app_label, seen)
+            prev_migration = seen[-1]
 
+            writer(
+                f'Updating migration "{conflict_path.name}" dependency to {prev_migration}'
+            )
+            _update_migration(conflict_path, app_label, prev_migration)
+
+            writer(
+                f'Renaming migration "{conflict_path.name}" to "{conflict_new_path.name}"'
+            )
             # Rename the migration file
             conflict_path.rename(conflict_new_path)
 
-            seen.append(new_conflict_name.strip(".py"))
-
-
-def fix_named_migration(
-    *,
-    app_label: str,
-    migration_path: Path,
-    start_name: str,
-    changed_files: List[str],
-):
-    """Resolve migration conflicts for named migrations."""
-    seen = [start_name]
-
-    for path in changed_files:
-        basename = os.path.basename(path)
-        conflict_path = migration_path / basename
-
-        with conflict_path:
-            _update_migration(conflict_path, app_label, seen)
-
-            seen.append(basename.strip(".py"))
+            seen.append(conflict_new_path.stem)
 
 
 def no_translations(handle_func):
